@@ -12,11 +12,14 @@
 package org.eclipse.tycho.p2.resolver;
 
 import java.io.File;
+import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
@@ -24,6 +27,7 @@ import java.util.Set;
 import java.util.TreeSet;
 
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.equinox.internal.p2.metadata.InstallableUnit;
 import org.eclipse.equinox.p2.metadata.IArtifactKey;
 import org.eclipse.equinox.p2.metadata.IInstallableUnit;
 import org.eclipse.equinox.p2.metadata.IProvidedCapability;
@@ -31,6 +35,7 @@ import org.eclipse.equinox.p2.metadata.IRequirement;
 import org.eclipse.equinox.p2.metadata.MetadataFactory;
 import org.eclipse.equinox.p2.metadata.MetadataFactory.InstallableUnitDescription;
 import org.eclipse.equinox.p2.metadata.VersionRange;
+import org.eclipse.equinox.p2.metadata.expression.IMatchExpression;
 import org.eclipse.equinox.p2.publisher.eclipse.BundlesAction;
 import org.eclipse.equinox.p2.query.IQueryResult;
 import org.eclipse.equinox.p2.query.QueryUtil;
@@ -43,7 +48,6 @@ import org.eclipse.tycho.artifacts.DependencyResolutionException;
 import org.eclipse.tycho.artifacts.IllegalArtifactReferenceException;
 import org.eclipse.tycho.artifacts.TargetPlatform;
 import org.eclipse.tycho.core.ee.shared.ExecutionEnvironmentConfigurationStub;
-import org.eclipse.tycho.core.shared.BuildFailureException;
 import org.eclipse.tycho.core.shared.MavenLogger;
 import org.eclipse.tycho.core.shared.MultiLineLogger;
 import org.eclipse.tycho.core.shared.TargetEnvironment;
@@ -102,18 +106,28 @@ public class P2ResolverImpl implements P2Resolver {
     }
 
     @Override
-    public List<P2ResolutionResult> resolveDependencies(TargetPlatform targetPlatform, ReactorProject project) {
+    public Map<TargetEnvironment, P2ResolutionResult> resolveTargetDependencies(TargetPlatform targetPlatform,
+            ReactorProject project) {
         setContext(targetPlatform, project);
 
         if (project != null && PackagingType.TYPE_ECLIPSE_TEST_PLUGIN.equals(project.getPackaging())) {
             addDependenciesForTests();
         }
 
-        ArrayList<P2ResolutionResult> results = new ArrayList<>();
+        // we need a linked hashmap to maintain iteration-order, some of the code relies on it!
+        Map<TargetEnvironment, P2ResolutionResult> results = new LinkedHashMap<>();
         usedTargetPlatformUnits = new LinkedHashSet<>();
-
+        Set<?> metadata = project != null ? project.getDependencyMetadata(true) : Collections.emptySet();
         for (TargetEnvironment environment : environments) {
-            results.add(resolveDependencies(project, new ProjectorResolutionStrategy(logger), environment));
+            if (isMatchingEnv(metadata, environment)) {
+                results.put(environment,
+                        resolveDependencies(project, new ProjectorResolutionStrategy(logger), environment));
+            } else {
+                logger.info(MessageFormat.format(
+                        "Project {0}:{1}:{2} does not match environment {3} skipp dependecy resolution",
+                        project.getGroupId(), project.getArtifactId(), project.getVersion(),
+                        environment.toFilterExpression()));
+            }
         }
 
         context.reportUsedLocalIUs(usedTargetPlatformUnits);
@@ -122,6 +136,34 @@ public class P2ResolverImpl implements P2Resolver {
         return results;
     }
 
+    /**
+     * Check if the Metadata contains any constraints that forbid the given
+     * {@link TargetEnvironment}
+     * 
+     * @param metadata
+     * @param environment
+     * @return
+     */
+    private boolean isMatchingEnv(Set<?> metadata, TargetEnvironment environment) {
+        if (metadata != null) {
+            for (Object meta : metadata) {
+                if (meta instanceof IInstallableUnit) {
+                    IMatchExpression<IInstallableUnit> filter = ((IInstallableUnit) meta).getFilter();
+                    if (filter != null) {
+                        boolean match = filter.isMatch(InstallableUnit.contextIU(environment.toFilterProperties()));
+                        logger.debug(MessageFormat.format("{0}: {1} (matches {2})", filter,
+                                Arrays.toString(filter.getParameters()), match));
+                        if (!match) {
+                            return false;
+                        }
+                    }
+                }
+            }
+        }
+        return true;
+
+    }
+
     @Override
     public P2ResolutionResult collectProjectDependencies(TargetPlatform targetPlatform, ReactorProject project) {
         setContext(targetPlatform, project);
@@ -199,7 +241,7 @@ public class P2ResolverImpl implements P2Resolver {
             new MultiLineLogger(logger).error(e.getDetails(), "  ");
             logger.error("");
             logger.error("See http://wiki.eclipse.org/Tycho/Dependency_Resolution_Troubleshooting for help.");
-            throw new DependencyResolutionException("Cannot resolve dependencies of " + project.toString(), e);
+            throw new DependencyResolutionException("Cannot resolve dependencies of " + project, e);
         }
 
         if (usedTargetPlatformUnits != null) {
@@ -209,7 +251,8 @@ public class P2ResolverImpl implements P2Resolver {
         return toResolutionResult(newState, project);
     }
 
-    private P2ResolutionResult toResolutionResult(Collection<IInstallableUnit> newState, ReactorProject currentProject) {
+    private P2ResolutionResult toResolutionResult(Collection<IInstallableUnit> newState,
+            ReactorProject currentProject) {
         DefaultP2ResolutionResult result = new DefaultP2ResolutionResult();
         Set<String> missingArtifacts = new TreeSet<>();
 
@@ -403,8 +446,8 @@ public class P2ResolverImpl implements P2Resolver {
         try {
             parsedVersionRange = new VersionRange(versionRange);
         } catch (IllegalArgumentException e) {
-            throw new IllegalArtifactReferenceException("The string \"" + versionRange
-                    + "\" is not a valid OSGi version range");
+            throw new IllegalArtifactReferenceException(
+                    "The string \"" + versionRange + "\" is not a valid OSGi version range");
         }
         additionalRequirements.add(ArtifactTypeHelper.createRequirementFor(type, id, parsedVersionRange));
     }
@@ -442,8 +485,8 @@ public class P2ResolverImpl implements P2Resolver {
         IRequirement requirement = MetadataFactory.createRequirement(IInstallableUnit.NAMESPACE_IU_ID, id, range, null,
                 1 /* min */, Integer.MAX_VALUE /* max */, false /* greedy */);
 
-        IQueryResult<IInstallableUnit> result = queriable.query(
-                QueryUtil.createLatestQuery(QueryUtil.createMatchQuery(requirement.getMatches())), monitor);
+        IQueryResult<IInstallableUnit> result = queriable
+                .query(QueryUtil.createLatestQuery(QueryUtil.createMatchQuery(requirement.getMatches())), monitor);
 
         Set<IInstallableUnit> newState = result.toUnmodifiableSet();
 
