@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2014 Sonatype Inc. and others.
+ * Copyright (c) 2008, 2019 Sonatype Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -57,10 +57,10 @@ public class TychoTest extends AbstractTychoMojoTestCase {
         List<MavenProject> projects = getSortedProjects(basedir);
         assertEquals(5, projects.size());
 
-        MavenProject p002 = (MavenProject) projects.get(1);
-        MavenProject p001 = (MavenProject) projects.get(2);
-        MavenProject p004 = (MavenProject) projects.get(3); // feature
-        MavenProject p003 = (MavenProject) projects.get(4); // site
+        MavenProject p002 = projects.get(1);
+        MavenProject p001 = projects.get(2);
+        MavenProject p004 = projects.get(3); // feature
+        MavenProject p003 = projects.get(4); // site
 
         assertEquals("moduleorder.p001", p001.getArtifactId());
         assertEquals("moduleorder.p002", p002.getArtifactId());
@@ -181,13 +181,14 @@ public class TychoTest extends AbstractTychoMojoTestCase {
         OsgiBundleProject projectType = (OsgiBundleProject) lookup(TychoProject.class, project.getPackaging());
 
         List<ClasspathEntry> classpath = projectType.getClasspath(project);
+
         assertEquals(3, classpath.size());
-        assertEquals(1, classpath.get(1).getLocations().size());
+        assertEquals(1, classpath.get(0).getLocations().size());
         assertEquals(canonicalFile("src/test/resources/targetplatforms/missingentry/plugins/dirbundle_0.0.1"),
-                classpath.get(1).getLocations().get(0).getCanonicalFile());
-        assertEquals(1, classpath.get(2).getLocations().size());
+                classpath.get(0).getLocations().get(0).getCanonicalFile());
+        assertEquals(1, classpath.get(1).getLocations().size());
         assertEquals(canonicalFile("src/test/resources/targetplatforms/missingentry/plugins/jarbundle_0.0.1.jar"),
-                classpath.get(2).getLocations().get(0).getCanonicalFile());
+                classpath.get(1).getLocations().get(0).getCanonicalFile());
     }
 
     private File canonicalFile(String path) throws IOException {
@@ -209,29 +210,30 @@ public class TychoTest extends AbstractTychoMojoTestCase {
         List<ClasspathEntry> classpath = projectType.getClasspath(b02);
 
         assertEquals(5, classpath.size());
-        // this bundle
-        assertEquals(1, classpath.get(0).getLocations().size());
-        assertEquals(canonicalFile("target/projects/extraclasspath/b02/target/classes"), classpath.get(0)
-                .getLocations().get(0).getCanonicalFile());
-        // reference to external bundle entry not on classpath
-        assertEquals(1, classpath.get(1).getLocations().size());
-        assertEquals(
-                canonicalFile("target/local-repo/.cache/tycho/org.eclipse.equinox.launcher_1.0.101.R34x_v20081125.jar/launcher.properties"),
-                classpath.get(1).getLocations().get(0).getCanonicalFile());
-        // reference to reactor project entry
-        assertEquals(1, classpath.get(2).getLocations().size());
-        assertEquals(canonicalFile("target/projects/extraclasspath/b01/target/lib/nested.jar-classes"), classpath
-                .get(2).getLocations().get(0).getCanonicalFile());
-        // reference to external bundle
-        assertEquals(1, classpath.get(3).getLocations().size());
-        assertEquals(
-                canonicalFile("src/test/resources/targetplatforms/basic/plugins/org.eclipse.equinox.launcher_1.0.101.R34x_v20081125.jar"),
-                classpath.get(3).getLocations().get(0).getCanonicalFile());
-        // reference to project local folder
-        assertEquals(1, classpath.get(4).getLocations().size());
-        assertEquals(new File(basedir, "b02/classes").getCanonicalFile(), classpath.get(4).getLocations().get(0)
-                .getCanonicalFile());
 
+        // reference to external bundle entry not on classpath
+        assertEquals(1, classpath.get(0).getLocations().size());
+        assertEquals(canonicalFile(
+                "target/local-repo/.cache/tycho/org.eclipse.equinox.launcher_1.0.101.R34x_v20081125.jar/launcher.properties"),
+                classpath.get(0).getLocations().get(0).getCanonicalFile());
+        // reference to reactor project entry
+        assertEquals(1, classpath.get(1).getLocations().size());
+        assertEquals(canonicalFile("target/projects/extraclasspath/b01/target/lib/nested.jar-classes"),
+                classpath.get(1).getLocations().get(0).getCanonicalFile());
+
+        // reference to external bundle
+        assertEquals(1, classpath.get(2).getLocations().size());
+        assertEquals(canonicalFile(
+                "src/test/resources/targetplatforms/basic/plugins/org.eclipse.equinox.launcher_1.0.101.R34x_v20081125.jar"),
+                classpath.get(2).getLocations().get(0).getCanonicalFile());
+        // reference to project local folder
+        assertEquals(1, classpath.get(3).getLocations().size());
+        assertEquals(new File(basedir, "b02/classes").getCanonicalFile(),
+                classpath.get(3).getLocations().get(0).getCanonicalFile());
+        // this bundle
+        assertEquals(1, classpath.get(4).getLocations().size());
+        assertEquals(canonicalFile("target/projects/extraclasspath/b02/target/classes"),
+                classpath.get(4).getLocations().get(0).getCanonicalFile());
     }
 
     public void testImplicitTargetEnvironment() throws Exception {
@@ -362,10 +364,10 @@ public class TychoTest extends AbstractTychoMojoTestCase {
         int i = 0;
 
         assertEquals("executionenvironment.manifest", projects.get(++i).getArtifactId());
-        assertEquals("CDC-1.1/Foundation-1.1", getActiveEEProfile(projects.get(i)));
+        assertEquals("OSGi/Minimum-1.0", getActiveEEProfile(projects.get(i)));
 
         assertEquals("executionenvironment.manifest-minimal", projects.get(++i).getArtifactId());
-        assertEquals("CDC-1.0/Foundation-1.0", getActiveEEProfile(projects.get(i)));
+        assertEquals("OSGi/Minimum-1.0", getActiveEEProfile(projects.get(i)));
 
         assertEquals("executionenvironment.pom-hard", projects.get(++i).getArtifactId());
         assertEquals("OSGi/Minimum-1.2", getActiveEEProfile(projects.get(i)));
