@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2016 Sonatype Inc. and others.
+ * Copyright (c) 2008, 2018 Sonatype Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -17,8 +17,6 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.net.URL;
-import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -28,6 +26,7 @@ import java.util.Properties;
 import java.util.Set;
 
 import org.apache.maven.plugin.surefire.StartupReportConfiguration;
+import org.apache.maven.plugin.surefire.log.api.PrintStreamLogger;
 import org.apache.maven.plugin.surefire.report.DefaultReporterFactory;
 import org.apache.maven.surefire.booter.BooterConstants;
 import org.apache.maven.surefire.booter.ClassLoaderConfiguration;
@@ -54,6 +53,7 @@ import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleException;
 
 public class OsgiSurefireBooter {
+    private static final String XSD = "https://maven.apache.org/surefire/maven-surefire-plugin/xsd/surefire-test-report.xsd";
 
     public static int run(String[] args) throws Exception {
         Properties testProps = loadProperties(getTestProperties(args));
@@ -65,6 +65,7 @@ public class OsgiSurefireBooter {
         File reportsDir = new File(testProps.getProperty("reportsdirectory"));
         String provider = testProps.getProperty("testprovider");
         String runOrder = testProps.getProperty("runOrder");
+        boolean trimStackTrace = Boolean.parseBoolean(testProps.getProperty("trimStackTrace", "true"));
         int skipAfterFailureCount = Integer.parseInt(testProps.getProperty("skipAfterFailureCount", "0"));
         int rerunFailingTestsCount = Integer.parseInt(testProps.getProperty("rerunFailingTestsCount", "0"));
         Map<String, String> propertiesMap = new HashMap<String, String>();
@@ -74,9 +75,13 @@ public class OsgiSurefireBooter {
         PropertiesWrapper wrapper = new PropertiesWrapper(propertiesMap);
         List<String> suiteXmlFiles = wrapper.getStringList(BooterConstants.TEST_SUITE_XML_FILES);
 
+        String timeoutParameter = testProps.getProperty("-timeout", null); //$NON-NLS-1$
+        if (timeoutParameter != null) {
+            DumpStackTracesTimer.startStackDumpTimeoutTimer(timeoutParameter);
+        }
+
         boolean forkRequested = true;
         boolean inForkedVM = true;
-        boolean trimStacktrace = true;
         boolean useSystemClassloader = false;
         boolean useManifestOnlyJar = false;
         boolean useFile = true;
@@ -91,17 +96,18 @@ public class OsgiSurefireBooter {
         DirectoryScannerParameters dirScannerParams = new DirectoryScannerParameters(testClassesDir,
                 Collections.<String> emptyList(), Collections.<String> emptyList(), Collections.<String> emptyList(),
                 failIfNoTests, runOrder);
-        ReporterConfiguration reporterConfig = new ReporterConfiguration(reportsDir, trimStacktrace);
+        ReporterConfiguration reporterConfig = new ReporterConfiguration(reportsDir, trimStackTrace);
         TestRequest testRequest = new TestRequest(suiteXmlFiles, testClassesDir,
                 TestListResolver.getEmptyTestListResolver());
         ProviderConfiguration providerConfiguration = new ProviderConfiguration(dirScannerParams,
                 new RunOrderParameters(runOrder, null), failIfNoTests, reporterConfig, null, testRequest,
                 extractProviderProperties(testProps), null, false, Collections.<CommandLineOption> emptyList(),
-                skipAfterFailureCount, Shutdown.DEFAULT);
+                skipAfterFailureCount, Shutdown.DEFAULT, 30);
         StartupReportConfiguration startupReportConfig = new StartupReportConfiguration(useFile, printSummary,
                 StartupReportConfiguration.PLAIN_REPORT_FORMAT, redirectTestOutputToFile, disableXmlReport, reportsDir,
-                trimStacktrace, null, "TESTHASH", false, rerunFailingTestsCount);
-        ReporterFactory reporterFactory = new DefaultReporterFactory(startupReportConfig);
+                trimStackTrace, null, new File(reportsDir, "TESTHASH"), false, rerunFailingTestsCount, XSD, null);
+        ReporterFactory reporterFactory = new DefaultReporterFactory(startupReportConfig,
+                new PrintStreamLogger(startupReportConfig.getOriginalSystemOut()));
         // API indicates we should use testClassLoader below but surefire also tries 
         // to load surefire classes using this classloader
         RunResult result = ProviderFactory.invokeProvider(null, createCombinedClassLoader(testPlugin), reporterFactory,
@@ -112,8 +118,12 @@ public class OsgiSurefireBooter {
 
     private static ClassLoader createCombinedClassLoader(String testPlugin) throws BundleException {
         ClassLoader testClassLoader = getBundleClassLoader(testPlugin);
+        ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
         ClassLoader surefireClassLoader = ForkedBooter.class.getClassLoader();
-        return new CombinedClassLoader(testClassLoader, surefireClassLoader);
+        return new CombinedClassLoader(testClassLoader, surefireClassLoader,
+                // Not used contextClassLoader directly because it's a ContextFinder
+                // which not work with tycho sufire osgibooster bundle
+                new ContextFinderWithoutTychoBundle(contextClassLoader.getParent()));
     }
 
     /*
@@ -148,14 +158,6 @@ public class OsgiSurefireBooter {
                 null));
     }
 
-    private static List<String> getIncludesExcludes(String string) {
-        ArrayList<String> list = new ArrayList<String>();
-        if (string != null) {
-            list.addAll(Arrays.asList(string.split(",")));
-        }
-        return list;
-    }
-
     private static Properties loadProperties(File file) throws IOException {
         Properties p = new Properties();
         BufferedInputStream in = new BufferedInputStream(new FileInputStream(file));
@@ -189,7 +191,6 @@ public class OsgiSurefireBooter {
             }
             throw ex;
         }
-
         return new BundleClassLoader(bundle);
     }
 
@@ -200,15 +201,18 @@ public class OsgiSurefireBooter {
             this.bundle = target;
         }
 
-        protected Class findClass(String name) throws ClassNotFoundException {
+        @Override
+        protected Class<?> findClass(String name) throws ClassNotFoundException {
             return bundle.loadClass(name);
         }
 
+        @Override
         protected URL findResource(String name) {
             return bundle.getResource(name);
         }
 
-        protected Enumeration findResources(String name) throws IOException {
+        @Override
+        protected Enumeration<URL> findResources(String name) throws IOException {
             return bundle.getResources(name);
         }
     }
